@@ -37,9 +37,12 @@
     Updated by      Richard Gooch   11-SEP-1998: Fixed bug in <read_config>
   where <<line>> pointer was dereferenced before being initialised.
 
-    Last updated by Richard Gooch   9-JUN-1999: Added variable expansion
+    Updated by      Richard Gooch   9-JUN-1999: Added variable expansion
   support.
 
+    Last updated by Richard Gooch   10-JUN-1999: Added "devname" variable and
+  renamed "device" variable name to "devpath".
+
 
 */
 #include <stdio.h>
@@ -64,7 +67,7 @@
 #include <karma.h>
 
 
-#define VERSION "1.2.0"
+#define VERSION "1.2.1"
 #define CONFIG_FILE "/etc/devfsd.conf"
 #define MAX_ARGS 6
 
@@ -661,7 +664,8 @@ static void sig_handler (int sig)
 
 static CONST char *get_variable (CONST char *variable, void *info)
 {
-    if (strcmp (variable, "device") == 0) return (info);
+    if (strcmp (variable, "devpath") == 0) return (info);
+    if (strcmp (variable, "devname") == 0) return strchr (info, '/') + 1;
     return (NULL);
 }   /*  End Function get_variable  */
 
